aboutsummaryrefslogtreecommitdiffstats
path: root/drivers/multiple/Win32
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/multiple/Win32')
-rw-r--r--drivers/multiple/Win32/gdisp_lld_Win32.c24
-rw-r--r--drivers/multiple/Win32/gdisp_lld_config.h22
-rw-r--r--drivers/multiple/Win32/readme.txt8
3 files changed, 27 insertions, 27 deletions
diff --git a/drivers/multiple/Win32/gdisp_lld_config.h b/drivers/multiple/Win32/gdisp_lld_config.h
index 4178a948..710cd3fb 100644
--- a/drivers/multiple/Win32/gdisp_lld_config.h
+++ b/drivers/multiple/Win32/gdisp_lld_config.h
@@ -17,31 +17,31 @@
// Calling gdispGFlush() is optional for this driver but can be used by the
// application to force a display update. eg after streaming.
-#define GDISP_HARDWARE_FLUSH TRUE
-#define GDISP_HARDWARE_CONTROL TRUE
+#define GDISP_HARDWARE_FLUSH GFXON
+#define GDISP_HARDWARE_CONTROL GFXON
//#define GDISP_WIN32_STREAMING_TEST
#ifdef GDISP_WIN32_STREAMING_TEST
// These streaming routines are here only to debug the high level gdisp
// code for streaming controllers. They are slow, inefficient and have
// lots of debugging turned on.
- #define GDISP_HARDWARE_STREAM_WRITE TRUE
- #define GDISP_HARDWARE_STREAM_READ TRUE
- #define GDISP_HARDWARE_STREAM_POS TRUE
+ #define GDISP_HARDWARE_STREAM_WRITE GFXON
+ #define GDISP_HARDWARE_STREAM_READ GFXON
+ #define GDISP_HARDWARE_STREAM_POS GFXON
#else
// The proper way on the Win32. These routines are nice and fast.
- #define GDISP_HARDWARE_DRAWPIXEL TRUE
- #define GDISP_HARDWARE_FILLS TRUE
- #define GDISP_HARDWARE_PIXELREAD TRUE
- #define GDISP_HARDWARE_SCROLL TRUE
+ #define GDISP_HARDWARE_DRAWPIXEL GFXON
+ #define GDISP_HARDWARE_FILLS GFXON
+ #define GDISP_HARDWARE_PIXELREAD GFXON
+ #define GDISP_HARDWARE_SCROLL GFXON
// Bit-blits on Win32 are currently only supported for True-Color bit-depths greater than 8 bits
// Note: At the time this file is included we have not calculated all our color
// definitions so we need to do this by hand.
#if !defined(GDISP_PIXELFORMAT)
- #define GDISP_HARDWARE_BITFILLS TRUE
+ #define GDISP_HARDWARE_BITFILLS GFXON
#elif (GDISP_PIXELFORMAT & 0x2000) && (((GDISP_PIXELFORMAT & 0x0F00)>>8)+((GDISP_PIXELFORMAT & 0x00F0)>>4)+((GDISP_PIXELFORMAT & 0x000F))) > 8
- #define GDISP_HARDWARE_BITFILLS TRUE
+ #define GDISP_HARDWARE_BITFILLS GFXON
#endif
#endif
diff --git a/drivers/multiple/Win32/readme.txt b/drivers/multiple/Win32/readme.txt
index 932deb8b..47080f73 100644
--- a/drivers/multiple/Win32/readme.txt
+++ b/drivers/multiple/Win32/readme.txt
@@ -4,10 +4,10 @@ This driver is special in that it implements both the gdisp low level driver,
optionally a touchscreen driver, and optionally a toggle driver.
1. Add in your gfxconf.h:
- a) #define GFX_USE_GDISP TRUE
- b) Optionally #define GFX_USE_GINPUT TRUE
- #define GINPUT_USE_MOUSE TRUE
- #define GINPUT_USE_TOGGLE TRUE
+ a) #define GFX_USE_GDISP GFXON
+ b) Optionally #define GFX_USE_GINPUT GFXON
+ #define GINPUT_USE_MOUSE GFXON
+ #define GINPUT_USE_TOGGLE GFXON
c) Any optional high level driver defines (see gdisp.h) eg: GDISP_NEED_MULTITHREAD
d) Optionally the following (with appropriate values):
#define GDISP_SCREEN_WIDTH 640
diff --git a/drivers/multiple/Win32/gdisp_lld_Win32.c b/drivers/multiple/Win32/gdisp_lld_Win32.c
index a724769d..0ce0f25a 100644
--- a/drivers/multiple/Win32/gdisp_lld_Win32.c
+++ b/drivers/multiple/Win32/gdisp_lld_Win32.c
@@ -25,7 +25,7 @@
#endif
#ifndef GDISP_WIN32_USE_INDIRECT_UPDATE
/**
* Setting this to TRUE delays updating the screen
* to the windows paint routine. Due to the
* drawing lock this does not add as much speed
* as might be expected but it is still faster in
@@ -37,20 +37,20 @@
* if you are debugging drawing and want to see each
* pixel as it is set.
*/
- #define GDISP_WIN32_USE_INDIRECT_UPDATE TRUE
+ #define GDISP_WIN32_USE_INDIRECT_UPDATE GFXON
#endif
#ifndef GKEYBOARD_WIN32_NO_LAYOUT
/**
* Setting this to TRUE turns off the layout engine.
* In this situation "cooked" characters are returned but
* shift states etc are lost.
* As only a limited number of keyboard layouts are currently
* defined for Win32 in uGFX (currently only US English), setting this
* to TRUE enables the windows keyboard mapping to be pass non-English
* characters to uGFX or to handle non-standard keyboard layouts at
* the expense of losing special function keys etc.
*/
- #define GKEYBOARD_WIN32_NO_LAYOUT FALSE
+ #define GKEYBOARD_WIN32_NO_LAYOUT GFXOFF
#endif
#ifndef GKEYBOARD_WIN32_DEFAULT_LAYOUT
#define GKEYBOARD_WIN32_DEFAULT_LAYOUT KeyboardLayout_Win32_US
@@ -136,7 +136,7 @@
#if !GKEYBOARD_WIN32_NO_LAYOUT
#if GKEYBOARD_LAYOUT_OFF
#error "The Win32 keyboard driver is using the layout engine. Please set GKEYBOARD_LAYOUT_OFF=FALSE or GKEYBOARD_WIN32_NO_LAYOUT=TRUE."
#endif
#include "../../../src/ginput/ginput_keyboard_microcode.h"
@@ -381,9 +381,9 @@
};
#elif !GKEYBOARD_LAYOUT_OFF
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
#warning "The WIN32 keyboard driver is not using the layout engine. If no other keyboard is using it consider defining GKEYBOARD_LAYOUT_OFF=TRUE to save code size."
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO
- COMPILER_WARNING("The WIN32 keyboard driver is not using the layout engine. If no other keyboard is using it consider defining GKEYBOARD_LAYOUT_OFF=TRUE to save code size.")
+ COMPILER_WARNING("The WIN32 keyboard driver is not using the layout engine. If no other keyboard is using it consider defining GKEYBOARD_LAYOUT_OFF=GFXON to save code size.")
#endif
#endif
@@ -467,7 +467,7 @@ void gfxEmulatorSetParentWindow(void *hwnd) {
priv->mousebuttons = buttons;
priv->mousex = x;
priv->mousey = y;
- if ((gmvmt(priv->mouse)->d.flags & GMOUSE_VFLG_NOPOLL)) // For normal setup this is always TRUE
+ if ((gmvmt(priv->mouse)->d.flags & GMOUSE_VFLG_NOPOLL)) // For normal setup this is always true
_gmouseWakeup(priv->mouse);
}
void gfxEmulatorMouseEnable(GDisplay *g, bool_t enabled) {
@@ -634,7 +634,7 @@ static LRESULT myWindowProc(HWND hWnd, UINT Msg, WPARAM wParam, LPARAM lParam)
priv->mousebuttons = btns;
priv->mousex = (coord_t)LOWORD(lParam);
priv->mousey = (coord_t)HIWORD(lParam);
- if ((gmvmt(priv->mouse)->d.flags & GMOUSE_VFLG_NOPOLL)) // For normal setup this is always TRUE
+ if ((gmvmt(priv->mouse)->d.flags & GMOUSE_VFLG_NOPOLL)) // For normal setup this is always true
_gmouseWakeup(priv->mouse);
}
break;
@@ -652,7 +652,7 @@ static LRESULT myWindowProc(HWND hWnd, UINT Msg, WPARAM wParam, LPARAM lParam)
else if (HIWORD(lParam) & KF_REPEAT)
keybuffer[keypos++] = 0x01; // Repeat
keybuffer[keypos++] = wParam;
- if ((gkvmt(keyboard)->d.flags & GKEYBOARD_VFLG_NOPOLL)) // For normal setup this is always TRUE
+ if ((gkvmt(keyboard)->d.flags & GKEYBOARD_VFLG_NOPOLL)) // For normal setup this is always true
_gkeyboardWakeup(keyboard);
}
return 0;
@@ -666,7 +666,7 @@ static LRESULT myWindowProc(HWND hWnd, UINT Msg, WPARAM wParam, LPARAM lParam)
w = wParam;
len = WideCharToMultiByte(CP_UTF8, 0, &w, 1, (char *)(keybuffer+keypos), sizeof(keybuffer)-keypos, 0, 0);
keypos += len;
- if (len && (gkvmt(keyboard)->d.flags & GKEYBOARD_VFLG_NOPOLL)) // For normal setup this is always TRUE
+ if (len && (gkvmt(keyboard)->d.flags & GKEYBOARD_VFLG_NOPOLL)) // For normal setup this is always true
_gkeyboardWakeup(keyboard);
}
return 0;
@@ -25,7 +25,7 @@
#ifndef GDISP_WIN32_USE_INDIRECT_UPDATE
/**
- * Setting this to TRUE delays updating the screen
+ * Setting this to GFXON delays updating the screen
* to the windows paint routine. Due to the
* drawing lock this does not add as much speed
@@ -37,20 +37,20 @@
#ifndef GKEYBOARD_WIN32_NO_LAYOUT
/**
- * Setting this to TRUE turns off the layout engine.
+ * Setting this to GFXON turns off the layout engine.
* In this situation "cooked" characters are returned but
* shift states etc are lost.
@@ -37,20 +37,20 @@
* As only a limited number of keyboard layouts are currently
* defined for Win32 in uGFX (currently only US English), setting this
- * to TRUE enables the windows keyboard mapping to be pass non-English
+ * to GFXON enables the windows keyboard mapping to be pass non-English
* characters to uGFX or to handle non-standard keyboard layouts at
* the expense of losing special function keys etc.
@@ -136,7 +136,7 @@
#if !GKEYBOARD_WIN32_NO_LAYOUT
#if GKEYBOARD_LAYOUT_OFF
- #error "The Win32 keyboard driver is using the layout engine. Please set GKEYBOARD_LAYOUT_OFF=FALSE or GKEYBOARD_WIN32_NO_LAYOUT=TRUE."
+ #error "The Win32 keyboard driver is using the layout engine. Please set GKEYBOARD_LAYOUT_OFF=GFXOFF or GKEYBOARD_WIN32_NO_LAYOUT=GFXON."
#endif
#include "../../../src/ginput/ginput_keyboard_microcode.h"
@@ -381,9 +381,9 @@
#elif !GKEYBOARD_LAYOUT_OFF
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
- #warning "The WIN32 keyboard driver is not using the layout engine. If no other keyboard is using it consider defining GKEYBOARD_LAYOUT_OFF=TRUE to save code size."
+ #warning "The WIN32 keyboard driver is not using the layout engine. If no other keyboard is using it consider defining GKEYBOARD_LAYOUT_OFF=GFXON to save code size."
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO